@@ -25,13 +25,14 @@ test_that("Doesn't create empty directory for non self-contained RMarkdown", {
   test_rmd_src <- test_path("rmd", "test-not-self-contained.Rmd")
   test_rmd <- file.path(temp_dir, "test.Rmd")
   file.copy(test_rmd_src, test_rmd)
-  rmarkdown::render(test_rmd, quiet = TRUE)
+  expect_silent(rmarkdown::render(test_rmd, quiet = TRUE))
   out <- readLines(file.path(temp_dir, "test.html"))
 
   has_string <- function(str, n = 1L) {
     sum(grepl(str, out, fixed = FALSE)) == n
   }
 
+  skip_if_not(has_package_version("rmarkdown", "2.9"))
   expect_true(has_string('<meta method="KNIT_PRINT" ?/?>'))
   expect_true(has_string('<meta method="knit_print\\(2\\)" ?/?>'))
   expect_true(has_string('<meta method="INCLUDE_META\\(\\)" ?/?>'))
